# A Python package to manage all python files in a folder at once in console and do operation on it

## to download pndex
>pip install pndex

## usage :
> import pndex
<br>
> pndex.running()

### screenshot of the tool
![Screenshot](pndex.png)

## custom function you can use
>			colorchanger() - to change console color
>			enter_file_to_open() - to open py file
>			readit() - to read content of py file in console
>			open_in_notepad() - open file in notepad
>			open_in_vscode() - open file in vs code
>			reading_read_me() - read readme of python file if function is defined
>			install_py__module() - download python module directly
>			check_quality() - check quality of python file
>			file_info() - get information about file
>			clearscreen() - clear terminal
>			quitscreen() - quit program

## open this in folder where all .py file exists

##### thanks for reading readme